@@ -34,10 +34,10 @@ def add_dockerfile(path: str):
     
     if config.image_type == 'scrapy':
         with open(dockerfile_path, "wb") as f:
-            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/scrapy_dockerfile.txt'))
+            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/scrapy_dockerfile.txt').read())
     elif config.image_type == 'selenium':
         with open(dockerfile_path, "wb") as f:
-            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/selenium_dockerfile.txt'))
+            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/selenium_dockerfile.txt').read())
     else:
         raise Exception('image_type provided is invalid')
 
@@ -58,10 +58,10 @@ def add_worker_file(path: str):
 
     if return_type is str:
         with open(worker_file_path, "wb") as f:
-            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/path_output_worker.txt'))
+            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/path_output_worker.txt').read())
     elif return_type is list:
         with open(worker_file_path, "wb") as f:
-            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/data_output_worker.txt'))
+            f.write(pkg_resources.resource_stream('devopspipelinepoc', 'data/data_output_worker.txt').read())
     else:
         raise Exception('scrape function must return either a list or string')
 
